( cd opt/kde/share/doc/HTML/nl/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kig ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/amor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/karm ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kate ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmag ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kodo ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/korn ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kalzium ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/khangman ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kpercentage ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kandy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kdesu ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmail ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmoon ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kuser ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmousetool ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kompare ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kontact ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/konsole ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/konsolekalendar ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kverbos ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kweather ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kioslave ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/nl/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/nl/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kbruch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/keduca ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kgamma ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmouth ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmplot ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/knotes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kpager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kpilot ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kspell ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kstars ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/ktouch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/klettres ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kworldclock ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kteatime ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kmathtool ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/konqueror ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/korganizer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
